==> img-0.4.9.tar.gz: img-0.4.9/push.go <==
package main

import (
	"flag"
	"fmt"

	"github.com/containerd/containerd/namespaces"
	"github.com/genuinetools/img/client"
	"github.com/moby/buildkit/session"
	"github.com/moby/buildkit/util/appcontext"
	"golang.org/x/sync/errgroup"
)

const pushHelp = `Push an image or a repository to a registry.`

func (cmd *pushCommand) Name() string       { return "push" }
func (cmd *pushCommand) Args() string       { return "[OPTIONS] NAME[:TAG]" }
func (cmd *pushCommand) ShortHelp() string  { return pushHelp }
func (cmd *pushCommand) LongHelp() string   { return pushHelp }
func (cmd *pushCommand) Hidden() bool       { return false }
func (cmd *pushCommand) DoReexec() bool     { return true }
func (cmd *pushCommand) RequiresRunc() bool { return false }

func (cmd *pushCommand) Register(fs *flag.FlagSet) {
	fs.BoolVar(&cmd.insecure, "insecure-registry", false, "Push to insecure registry")
}

type pushCommand struct {
	image    string
	insecure bool
}

func (cmd *pushCommand) Run(args []string) (err error) {
	if len(args) < 1 {
		return fmt.Errorf("must pass an image or repository to push")
	}

	// Get the specified image.
	cmd.image = args[0]

	// Create the client.
	c, err := client.New(stateDir, backend, nil)
	if err != nil {
		return err
	}
	defer c.Close()

	fmt.Printf("Pushing %s...\n", cmd.image)

	// Create the context.
	ctx := appcontext.Context()
	sess, sessDialer, err := c.Session(ctx)
	if err != nil {
		return err
	}
	ctx = session.NewContext(ctx, sess.ID())
	ctx = namespaces.WithNamespace(ctx, "buildkit")
	eg, ctx := errgroup.WithContext(ctx)

	eg.Go(func() error {
		return sess.Run(ctx, sessDialer)
	})
	eg.Go(func() error {
		defer sess.Close()
		return c.Push(ctx, cmd.image, cmd.insecure)
	})
	if err := eg.Wait(); err != nil {
		return err
	}

	fmt.Printf("Successfully pushed %s\n", cmd.image)

	return nil
}

==> img-0.5.7.tar.gz: img-0.5.7/push.go <==
package main

import (
	"context"
	"flag"
	"fmt"

	"github.com/containerd/containerd/namespaces"
	"github.com/genuinetools/img/client"
	"github.com/moby/buildkit/session"
	"github.com/moby/buildkit/util/appcontext"
	"golang.org/x/sync/errgroup"
)

const pushHelp = `Push an image or a repository to a registry.`

func (cmd *pushCommand) Name() string      { return "push" }
func (cmd *pushCommand) Args() string      { return "[OPTIONS] NAME[:TAG]" }
func (cmd *pushCommand) ShortHelp() string { return pushHelp }
func (cmd *pushCommand) LongHelp() string  { return pushHelp }
func (cmd *pushCommand) Hidden() bool      { return false }

func (cmd *pushCommand) Register(fs *flag.FlagSet) {
	fs.BoolVar(&cmd.insecure, "insecure-registry", false, "Push to insecure registry")
}

type pushCommand struct {
	image    string
	insecure bool
}

func (cmd *pushCommand) Run(ctx context.Context, args []string) (err error) {
	if len(args) < 1 {
		return fmt.Errorf("must pass an image or repository to push")
	}

	reexec()

	// Get the specified image.
	cmd.image = args[0]

	// Create the client.
	c, err := client.New(stateDir, backend, nil)
	if err != nil {
		return err
	}
	defer c.Close()

	fmt.Printf("Pushing %s...\n", cmd.image)

	// Create the context.
	ctx = appcontext.Context()
	sess, sessDialer, err := c.Session(ctx)
	if err != nil {
		return err
	}
	ctx = session.NewContext(ctx, sess.ID())
	ctx = namespaces.WithNamespace(ctx, "buildkit")
	eg, ctx := errgroup.WithContext(ctx)

	eg.Go(func() error {
		return sess.Run(ctx, sessDialer)
	})
	eg.Go(func() error {
		defer sess.Close()
		return c.Push(ctx, cmd.image, cmd.insecure)
	})
	if err := eg.Wait(); err != nil {
		return err
	}

	fmt.Printf("Successfully pushed %s\n", cmd.image)

	return nil
}
